<img src="https://raw.githubusercontent.com/EasyScience/EasyCrystallography/refs/heads/master/resources/images/ec_logo.svg" height="65">

EasyCrystallography is a library used to generate and manipulate crystal structures within the [EasyScience](https://github.com/EasyScience) framework.

* Documentation: https://easyscience.github.io/EasyCrystallography
* Source code: https://github.com/EasyScience/EasyCrystallography
* Bug reports: https://github.com/EasyScience/EasyCrystallography/issues

## Contributing

We absolutely welcome contributions, and our goal is for EasyCrystallography to be a community-driven open source project developed by a diverse group of contributors.

EasyCrystallography is currently maintained by [European Spallation Source ERIC](https://ess.eu), Sweden.

If you are interested in contributing directly to the code, please see [CONTRIBUTING.md](https://raw.githubusercontent.com/EasyScience/EasyCrystallography/refs/heads/master/CONTRIBUTING.md) for details on our code of conduct and the process for submitting pull requests.

## License

EasyCrystallography is licensed under the [BSD 3-Clause License](https://raw.githubusercontent.com/EasyScience/EasyCrystallography/refs/heads/master/LICENSE).
